<?php 
/**
 * Plugin Name: Restrict Language Selection (Matomo Plugin)
 * Plugin URI: http://plugins.matomo.org/RestrictLanguageSelection
 * Description: Allows you to modify the list of available languages in language selector.
 * Author: Stefan Giehl
 * Author URI: https://github.com/sgiehl/piwik-plugin-RestrictLanguageSelection
 * Version: 5.0.0
 */
?><?php

/**
 * Matomo - Open source web analytics
 *
 * @link    https://matomo.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 */

namespace Piwik\Plugins\RestrictLanguageSelection;

use Piwik\Plugin;

/**
 *
 */
 
if (defined( 'ABSPATH')
&& function_exists('add_action')) {
    $path = '/matomo/app/core/Plugin.php';
    if (defined('WP_PLUGIN_DIR') && WP_PLUGIN_DIR && file_exists(WP_PLUGIN_DIR . $path)) {
        require_once WP_PLUGIN_DIR . $path;
    } elseif (defined('WPMU_PLUGIN_DIR') && WPMU_PLUGIN_DIR && file_exists(WPMU_PLUGIN_DIR . $path)) {
        require_once WPMU_PLUGIN_DIR . $path;
    } else {
        return;
    }
    add_action('plugins_loaded', function () {
        if (function_exists('matomo_add_plugin')) {
            matomo_add_plugin(__DIR__, __FILE__, true);
        }
    });
}

class RestrictLanguageSelection extends Plugin
{
    public static $disableRestrictions = false;

    /**
     * @see Piwik_Plugin::registerEvents
     */
    public function registerEvents()
    {
        return [
            'LanguagesManager.getAvailableLanguages' => 'modifyAvailableLanguages',
        ];
    }

    public function modifyAvailableLanguages(&$languages)
    {
        if (self::$disableRestrictions) {
            return;
        }

        $setting = new SystemSettings();

        if (!$setting->useRestriction->getValue()) {
            return; // setting disabled
        }

        $availableLanguages = $setting->availableLanguages->getValue();
        if (!empty($availableLanguages)) {
            $languages = $availableLanguages;
        }
    }
}
